@@ -214,6 +214,7 @@ users, which helped improve this program.
 
 (c) 2009-2010 by Eric O. LEBIGOT (EOL) <eric.lebigot@normalesup.org>.
 Please send feature requests, bug reports, or feedback to this address.
+Please support future development by donating $5 or more through PayPal!
 
 This software is released under a dual license.  (1) The GNU General
 Public License version 2.  (2) Any other license, as long as it is
@@ -234,10 +235,12 @@ import math
 from math import sqrt, log  # Optimization: no attribute look-up
 import copy
 
-__version__ = '1.5.3'
+__version__ = '1.5.4'
 # Numerical version:
 __version_info__ = tuple(int(num) for num in __version__.split('.'))
 
+__author__ = 'Eric O. LEBIGOT (EOL)'
+
 # Attributes that are always exported (some other attributes are
 # exported only if the NumPy module is available...):
 __all__ = [
@@ -245,8 +248,6 @@ __all__ = [
     # All sub-modules and packages are not imported by default,
     # because NumPy could not be installed:
 
-    'umath',  # Uncertainty-aware mathematical functions (module)
-
     'ufloat',  # Main function: returns a number with uncertainty
 
     # Uniform access to nominal values and standard deviations:
@@ -320,7 +321,7 @@ def to_affine_scalar(x):
     raise NotUpcast("%s cannot be converted to a number with"
                     " uncertainty" % type(x))
 
-def partial_derivative(f, param_num, step=1e-5):
+def partial_derivative(f, param_num):
     """
     Returns a function that numerically calculates the partial
     derivative of function f with respect to its argument number
@@ -338,7 +339,13 @@ def partial_derivative(f, param_num, step=1e-5):
         # f_nominal_value = f(*args)
 
         shifted_args = list(args)  # Copy, and conversion to a mutable
-        
+
+        # The step is relative to the parameter being varied, so that
+        # shifting it does not suffer from finite precision:
+        step = 1e-8*abs(shifted_args[param_num])
+        if not step:
+            step = 1e-8  # Arbitrary, but "small" with respect to 1
+
         shifted_args[param_num] += step
         shifted_f_plus = f(*shifted_args)
         
@@ -1016,10 +1023,10 @@ class Variable(AffineScalarFunc):
     # To save memory in large arrays:
     __slots__ = ('_std_dev', 'tag')
 
-    def __init__(self, value, std_dev=0, tag=None):
+    def __init__(self, value, std_dev, tag=None):
         """
         The nominal value and the standard deviation of the variable
-        are set.  These values must scalars.
+        are set.  These values must be scalars.
 
         'tag' is a tag that the user can associate to the variable.  This
         is useful for tracing variables.
@@ -1028,15 +1035,10 @@ class Variable(AffineScalarFunc):
         module documentation.
         """
 
-        #! The value, std_dev, and tag are assumed by __copy__() to not 
+        #! The value, std_dev, and tag are assumed by __copy__() not to
         # be copied.  Either this should be guaranteed here, or __copy__
         # should be updated.
 
-
-        assert isinstance(value, (int, float)), (
-            "Variable objects can only have a float-like"
-            " value.  Got type %s ('%s')." % (type(value), value))
-
         # Only float-like values are handled.  One reason is that the
         # division operator on integers would not produce a
         # differentiable functions: for instance, Variable(3, 0.1)/2
@@ -1375,11 +1377,11 @@ def ufloat(representation, tag=None):
     a standard deviation).
 
     The representation can be a (value, standard deviation) sequence,
-    or a simple number (in which case a zero uncertainty is implied).
+    or a string.
 
-    The representation can also be a string of the form
-    '12.345+/-0.015', '12.345(15)', or '12.3'.  In the last case,
-    an uncertainty of +/-1 is assigned to the last digit.
+    Strings of the form '12.345+/-0.015', '12.345(15)', or '12.3' are
+    recognized (see full list below).  In the last case, an
+    uncertainty of +/-1 is assigned to the last digit.
 
     'tag' is an optional string tag for the variable.  Variables
     don't have to have distinct tags.  Tags are useful for tracing
@@ -1404,8 +1406,12 @@ def ufloat(representation, tag=None):
         169.0(7)
     """
 
-    # We create the correct tuple of arguments 'init_args' for the
-    # Variable initialization.
+    # This function is somewhat optimized so as to help with the
+    # creation of lots of Variable objects (through unumpy.uarray, for
+    # instance).
+
+    # representations is "normalized" so as to be a valid sequence of
+    # 2 arguments for Variable().
 
     #! Accepting strings and any kind of sequence slows down the code
     # by about 5 %.  On the other hand, massive initializations of
@@ -1415,17 +1421,8 @@ def ufloat(representation, tag=None):
 
     #! Different, in Python 3:
     if isinstance(representation, basestring):
-        init_args = str_to_number_with_uncert(representation)
-    else:
-        try:  # This passes, for 2-character strings...
-            (value, std_dev) = representation
-        except TypeError:
-            # Case of a single float, integer, etc.:
-            init_args = (representation,)
-        else:
-            # The user provided a sequence with 2 elements:
-            init_args = representation
-
+        representation = str_to_number_with_uncert(representation)
+        
     #! The tag is forced to be a string, so that the user does not
     # create a Variable(2.5, 0.5) in order to represent 2.5
     # +/- 0.5.  Forcing 'tag' to be a string prevents errors from being
@@ -1437,7 +1434,7 @@ def ufloat(representation, tag=None):
                "The tag can only be a string."
 
     #! init_args must contain all arguments, here:
-    return Variable(*init_args, **{'tag': tag})
+    return Variable(*representation, **{'tag': tag})
 
 ###############################################################################
 # Support for legacy code (will be removed in the future):
