@@ -98,21 +98,23 @@ def test_monte_carlo_comparison():
     covariances_this_module = numpy.array(uncertainties.covariance_matrix(
         (x, y, function_result_this_module)))
 
-    def monte_carlo_calc(n_samples, ):
+    def monte_carlo_calc(n_samples):
         """
-        Calculate function(x, y) on n_samples and returns the median,
-        and the covariances between (x, y, function(x, y)).
+        Calculate function(x, y) on n_samples samples and returns the
+        median, and the covariances between (x, y, function(x, y)).
         """
         # Result of a Monte-Carlo simulation:
-        x_samples = numpy.random.normal(x.nominal_value, x.std_dev(), n_samples)
-        y_samples = numpy.random.normal(y.nominal_value, y.std_dev(), n_samples)
+        x_samples = numpy.random.normal(x.nominal_value, x.std_dev(),
+                                        n_samples)
+        y_samples = numpy.random.normal(y.nominal_value, y.std_dev(),
+                                        n_samples)
         function_samples = function(x_samples, y_samples)
 
         cov_mat = numpy.cov([x_samples, y_samples], function_samples)
         
         return (numpy.median(function_samples), cov_mat)
         
-    (nominal_value_samples, covariances_samples) = monte_carlo_calc(100000)
+    (nominal_value_samples, covariances_samples) = monte_carlo_calc(1000000)
 
 
     ## Comparison between both results:
@@ -128,8 +130,8 @@ def test_monte_carlo_comparison():
         0.05).all(), (
         "The covariance matrices do not coincide between"
         " the Monte-Carlo simulation and the direct calculation:\n"
-        "* Monte-Carlo:\n%s\n* Direct calculation:\n%s" %
-        (covariances_samples, covariances_this_module)
+        "* Monte-Carlo:\n%s\n* Direct calculation:\n%s"
+        % (covariances_samples, covariances_this_module)
         )
     
     # The nominal values must be close:
@@ -142,10 +144,10 @@ def test_monte_carlo_comparison():
         math.sqrt(covariances_samples[2, 2])
         / abs(nominal_value_samples) * 0.5), (
         "The nominal value (%f) does not coincide with that of"
-        " the Monte-Carlo simulation (%f), for a standard deviation of %f." %
-        (nominal_value_this_module,
-         nominal_value_samples,
-         math.sqrt(covariances_samples[2, 2]))
+        " the Monte-Carlo simulation (%f), for a standard deviation of %f."
+        % (nominal_value_this_module,
+           nominal_value_samples,
+           math.sqrt(covariances_samples[2, 2]))
         )
 
     
