@@ -127,7 +127,7 @@ def _compare_derivatives(func, numerical_derivatives,
 
                     # We compare all derivatives:
                     for (arg_num, (arg, numerical_deriv)) in \
-                          enumerate(zip(args, numerical_derivatives)):
+                        enumerate(zip(args, numerical_derivatives)):
 
                         # Some arguments might not be differentiable:
                         if isinstance(arg, int):
@@ -145,16 +145,16 @@ def _compare_derivatives(func, numerical_derivatives,
                         if not _numbers_close(fixed_deriv_value,
                                               num_deriv_value, 1e-4):
 
-                            # It is possible that the result is nan:
+                            # It is possible that the result is NaN:
 
-                            # ! Python 2.6: this would be
-                            # math.isnan(func_approx):
+                            # ! Python 2.6+: this would be
+                            # not math.isnan(func_approx):
                             if func_approx == func_approx:
                                 raise DerivativesDiffer(
                                     "Derivative #%d of function '%s' may be"
-                                    " wrong:"
-                                    " at args = %s, fixed val = %f,"
-                                    " while num. val = %f"
+                                    " wrong: at args = %s,"
+                                    " value obtained = %f,"
+                                    " while numerical approximation = %f."
                                     % (arg_num, func.__name__, args,
                                        fixed_deriv_value, num_deriv_value))
 
@@ -461,7 +461,7 @@ def test_basic_access_to_data():
 def test_correlations():
     "Correlations between variables"
 
-    a = ufloat(1)
+    a = ufloat((1, 0))
     x = ufloat((4, 0.1))
     y = x*2 + a
     # Correlations cancel "naive" additions of uncertainties:
